@@ -41,7 +41,10 @@ G_BEGIN_DECLS
 #define GM_STOCK_SPEAKER_PHONE    "gm_speaker_phone_stock"
 #define GM_STOCK_VIDEO_MUTE       "gm_video_mute_stock"
 #define GM_STOCK_STATUS_AVAILABLE "gm_status_available_stock"
-#define GM_STOCK_STATUS_OCCUPIED  "gm_status_busy_stock"
+#define GM_STOCK_STATUS_DO_NOT_DISTURB "gm_status_do_not_disturb_stock"
+#define GM_STOCK_STATUS_IN_A_CALL "gm_status_in_a_call_stock"
+#define GM_STOCK_STATUS_FORWARD  "gm_status_forward_stock"
+#define GM_STOCK_STATUS_AUTO_ANSWER "gm_status_auto_answer_stock"
 #define GM_STOCK_STATUS_RINGING   "gm_status_ringing_stock"
 #define GM_STOCK_DRUID_AUDIO      "gm_druid_audio_stock"
 #define GM_STOCK_DRUID_VIDEO      "gm_druid_video_stock"
