@@ -1,6 +1,6 @@
 
 /* GnomeMeeting -- A Video-Conferencing application
- * Copyright (C) 2000-2003 Damien Sandras
+ * Copyright (C) 2000-2004 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
  *                         sound_handling.h  -  description
  *                         --------------------------------
  *   begin                : Thu Nov 22 2001
- *   copyright            : (C) 2000-2003 by Damien Sandras
+ *   copyright            : (C) 2000-2004 by Damien Sandras
  *   description          : This file contains sound handling functions.
  *
  */
@@ -57,7 +57,7 @@ enum { SOURCE_AUDIO, SOURCE_MIC };
 /* DESCRIPTION   :  /
  * BEHAVIOR      : Puts ESD (and Artsd if support compiled in) into standby 
  *                 mode. An error message is displayed in the gnomemeeting
- *                 history if it failed. No message is displayed if it is
+ *                 log if it failed. No message is displayed if it is
  *                 succesful.
  * PRE           : /
  */
@@ -67,7 +67,7 @@ void gnomemeeting_sound_daemons_suspend ();
 /* DESCRIPTION   :  /
  * BEHAVIOR      : Puts ESD (and Artsd if support compiled in) into normal
  *                 mode. An error message is displayed in the gnomemeeting
- *                 history if it failed. No message is displayed if it is
+ *                 log if it failed. No message is displayed if it is
  *                 succesful.
  * PRE           : /
  */
@@ -145,8 +145,6 @@ protected:
   
   PMutex buffer_ring_access_mutex;
 
-  GmWindow *gw;
-  
   GtkWidget *test_label;
   GtkWidget *test_dialog;
   GtkWidget *level_meter;
